aboutsummaryrefslogtreecommitdiff
path: root/flake.nix
diff options
context:
space:
mode:
authorRaito Bezarius <raito@lix.systems>2024-05-14 02:05:08 +0200
committerRaito Bezarius <raito@lix.systems>2024-06-01 20:31:24 +0200
commitb8cb7abcf08be01a291c970164a3f44dfca0ddbf (patch)
tree727912b4e44d9f68d4e26e9d11b0719af4a0c554 /flake.nix
parent5312e60be6aba84fab91e6d82af0b1aeccdfe981 (diff)
chore: rebrand Nix to Lix when it makes sense
Here's my guide so far: $ rg '((?!(recursive).*) Nix (?!(daemon|store|expression|Rocks!|Packages|language|derivation|archive|account|user|sandbox|flake).*))' -g '!doc/' --pcre2 All items from this query have been tackled. For the documentation side: that's for https://git.lix.systems/lix-project/lix/issues/162. Additionally, all remaining references to github.com/NixOS/nix which were not relevant were also replaced. Fixes: https://git.lix.systems/lix-project/lix/issues/148. Fixes: https://git.lix.systems/lix-project/lix/issues/162. Change-Id: Ib3451fae5cb8ab8cd9ac9e4e4551284ee6794545 Signed-off-by: Raito Bezarius <raito@lix.systems>
Diffstat (limited to 'flake.nix')
-rw-r--r--flake.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/flake.nix b/flake.nix
index 14ee8e1ad..66b836f03 100644
--- a/flake.nix
+++ b/flake.nix
@@ -240,7 +240,7 @@
system: binaryTarball nixpkgsFor.${system}.native.nix nixpkgsFor.${system}.native
);
# docker image with Nix inside
dockerImage = lib.genAttrs linux64BitSystems (system: self.packages.${system}.dockerImage);
# API docs for Nix's unstable internal C++ interfaces.
@@ -336,7 +336,7 @@
};
in
pkgs.runCommand "docker-image-tarball-${version}"
- { meta.description = "Docker image with Nix for ${system}"; }
+ { meta.description = "Docker image with Lix for ${system}"; }
''
mkdir -p $out/nix-support
image=$out/image.tar.gz
@@ -240,7 +240,7 @@
system: binaryTarball nixpkgsFor.${system}.native.nix nixpkgsFor.${system}.native
);
- # docker image with Nix inside
+ # docker image with Lix inside
dockerImage = lib.genAttrs linux64BitSystems (system: self.packages.${system}.dockerImage);
# API docs for Nix's unstable internal C++ interfaces.